==> phonon-backend-vlc-0.3.2.tar.bz2: phonon-backend-vlc-0.3.2/vlc/vlc.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=PhononBackend
MimeType=application/x-annodex;video/quicktime;video/x-quicktime;audio/x-m4a;application/x-quicktimeplayer;video/mkv;video/msvideo;video/x-msvideo;video/x-flic;audio/x-aiff;audio/aiff;audio/x-pn-aiff;audio/x-realaudio;audio/basic;audio/x-basic;audio/x-pn-au;audio/x-8svx;audio/8svx;audio/x-16sv;audio/168sv;image/x-ilbm;image/ilbm;video/x-anim;video/anim;image/png;image/x-png;video/mng;video/x-mng;audio/x-ogg;audio/x-speex+ogg;application/ogg;application/ogg;audio/vnd.rn-realaudio;audio/x-pn-realaudio-plugin;audio/x-real-audio;application/vnd.rn-realmedia;video/mpeg;video/x-mpeg;audio/x-wav;audio/wav;audio/x-pn-wav;audio/x-pn-windows-acm;audio/mpeg2;audio/x-mpeg2;audio/mpeg3;audio/x-mpeg3;audio/mpeg;audio/x-mpeg;x-mpegurl;audio/x-mpegurl;audio/mp3;audio/mpeg;video/x-ms-asf;application/x-flash-video;
X-KDE-Library=phonon_vlc
X-KDE-PhononBackendInfo-InterfaceVersion=1
X-KDE-PhononBackendInfo-Version=@PHONON_VLC_VERSION@
X-KDE-PhononBackendInfo-Website=http://www.videolan.org/
Icon=vlc
InitialPreference=10

Name=VLC
Name[ca]=VLC
Name[ca@valencia]=VLC
Name[cs]=VLC
Name[da]=VLC
Name[es]=VLC
Name[et]=VLC
Name[hu]=VLC
Name[nds]=VLC
Name[nl]=VLC
Name[pt]=VLC
Name[pt_BR]=VLC
Name[sr]=ВЛЦ
Name[sr@ijekavian]=ВЛЦ
Name[sr@ijekavianlatin]=VLC
Name[sr@latin]=VLC
Name[sv]=VLC
Name[uk]=VLC
Name[x-test]=xxVLCxx

Comment=Phonon VLC backend
Comment[ca]=Dorsal del VLC pel Phonon
Comment[ca@valencia]=Dorsal del VLC pel Phonon
Comment[cs]=Podpůrná vrstva VLC
Comment[da]=Phonon VLC-motor
Comment[es]=Motor VLC para Phonon
Comment[et]=Phononi VLC taustaprogramm
Comment[hu]=Phonon VLC-backend
Comment[nds]=VLC-Hülpprogramm för Phonon
Comment[nl]=VLC-backend van Phonon
Comment[pt]=Infra-estrutura do VLC para o Phonon
Comment[pt_BR]=Infraestrutura do VLC para o Phonon
Comment[sr]=ВЛЦ као позадина Фонона
Comment[sr@ijekavian]=ВЛЦ као позадина Фонона
Comment[sr@ijekavianlatin]=VLC kao pozadina Phonona
Comment[sr@latin]=VLC kao pozadina Phonona
Comment[sv]=Phonon VLC-gränssnitt
Comment[uk]=Модуль VLC Phonon
Comment[x-test]=xxPhonon VLC backendxx

==> phonon-backend-vlc-0.4.0.tar.bz2: phonon-backend-vlc-0.4.0/vlc/vlc.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=PhononBackend
MimeType=application/x-annodex;video/quicktime;video/x-quicktime;audio/x-m4a;application/x-quicktimeplayer;video/mkv;video/msvideo;video/x-msvideo;video/x-flic;audio/x-aiff;audio/aiff;audio/x-pn-aiff;audio/x-realaudio;audio/basic;audio/x-basic;audio/x-pn-au;audio/x-8svx;audio/8svx;audio/x-16sv;audio/168sv;image/x-ilbm;image/ilbm;video/x-anim;video/anim;image/png;image/x-png;video/mng;video/x-mng;audio/x-ogg;audio/x-speex+ogg;application/ogg;application/ogg;audio/vnd.rn-realaudio;audio/x-pn-realaudio-plugin;audio/x-real-audio;application/vnd.rn-realmedia;video/mpeg;video/x-mpeg;audio/x-wav;audio/wav;audio/x-pn-wav;audio/x-pn-windows-acm;audio/mpeg2;audio/x-mpeg2;audio/mpeg3;audio/x-mpeg3;audio/mpeg;audio/x-mpeg;x-mpegurl;audio/x-mpegurl;audio/mp3;audio/mpeg;video/x-ms-asf;application/x-flash-video;
X-KDE-Library=phonon_vlc
X-KDE-PhononBackendInfo-InterfaceVersion=1
X-KDE-PhononBackendInfo-Version=@PHONON_VLC_VERSION@
X-KDE-PhononBackendInfo-Website=http://www.videolan.org/
Icon=vlc
InitialPreference=10

Name=VLC
Name[ca]=VLC
Name[ca@valencia]=VLC
Name[cs]=VLC
Name[da]=VLC
Name[de]=VLC
Name[es]=VLC
Name[et]=VLC
Name[hu]=VLC
Name[nds]=VLC
Name[nl]=VLC
Name[pa]=VLC
Name[pt]=VLC
Name[pt_BR]=VLC
Name[ru]=VLC
Name[sr]=ВЛЦ
Name[sr@ijekavian]=ВЛЦ
Name[sr@ijekavianlatin]=VLC
Name[sr@latin]=VLC
Name[sv]=VLC
Name[uk]=VLC
Name[x-test]=xxVLCxx
Name[zh_TW]=VLC

Comment=Phonon VLC backend
Comment[ca]=Dorsal del VLC pel Phonon
Comment[ca@valencia]=Dorsal del VLC pel Phonon
Comment[cs]=Podpůrná vrstva VLC
Comment[da]=Phonon VLC-motor
Comment[de]=Phonon-Treiber für VLC
Comment[es]=Motor VLC para Phonon
Comment[et]=Phononi VLC taustaprogramm
Comment[hu]=Phonon VLC-backend
Comment[nds]=VLC-Hülpprogramm för Phonon
Comment[nl]=VLC-backend van Phonon
Comment[pa]=ਫੋਨੋਨ VLC ਬੈਕਐਂਡ
Comment[pt]=Infra-estrutura do VLC para o Phonon
Comment[pt_BR]=Infraestrutura do VLC para o Phonon
Comment[ru]=Механизм VLC для Phonon
Comment[sr]=ВЛЦ као позадина Фонона
Comment[sr@ijekavian]=ВЛЦ као позадина Фонона
Comment[sr@ijekavianlatin]=VLC kao pozadina Phonona
Comment[sr@latin]=VLC kao pozadina Phonona
Comment[sv]=Phonon VLC-gränssnitt
Comment[uk]=Модуль VLC Phonon
Comment[x-test]=xxPhonon VLC backendxx
Comment[zh_TW]=Phonon VLC 後端介面
